import uuid


class User():
    def __init__(self, is_new = False, is_system_user=False, role_profile_name=None):
        self.username = ''
        self.new_password = ''
        self.enabled = 1
        self.first_name= ''
        self.last_name = ''
        self.role_profile_name = ''
        self.send_welcome_email = 0
        if is_new:
            self.reset_password_key = self.genkey()
            self.enabled = 0
        if role_profile_name:
            self.role_profile_name = role_profile_name
        if is_system_user:
            self.user_type = 'System User'
        else:
            self.user_type = 'Website User'


    def genkey(self) -> str:
        return uuid.uuid4().hex.upper()


class ApiKeyCredential():
    def __init__(self, api_key, api_secret, token_type='token'):
        self.api_key = api_key
        self.api_secret = api_secret
        self.token_type = token_type
        


from setuptools import setup, find_packages

setup(
    name="neo-sdk",
    version="0.1.0",
    description="SDK de conexão com o NEO Framework",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author="Luiz Carvalho",
    author_email="dev@mtmtecnologia.com.br",
    url="https://github.com/seuusuario/neo-sdk",
    packages=find_packages(),
    install_requires=[
        "requests>=2.26.0"
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.11",
)